from hysop.domain.box import Box
from hysop.constants import np, HDF5
from hysop.fields.continuous import Field
from hysop.operator.spectrum import Spectrum
from hysop.tools.parameters import Discretization, IOParams
from hysop.problem.simulation import Simulation
from hysop.operator.hdf_io import HDF_Writer
pi = np.pi
sin = np.sin
cos = np.cos


def computeScal(res, x, y, z, t):
    res[0][...] = z * sin((3*pi*x)*(2*pi*y))
    return res


def test_spectrum():
    dom = Box(origin=[0., 0., 0.], length=[1., 1., 1.])
    field = Field(domain=dom, name='Field',
                  is_vector=False, formula=computeScal)
    d3D = Discretization([257, 257, 257])

    op = Spectrum(field, discretization=d3D)
    op.discretize()
    op.setup()
    topo = op.discreteFields[field].topology
    field.initialize(topo=topo)

    prt = HDF_Writer(variables={field: topo, },
                     io_params=IOParams(frequency=1,
                                        filename='field',
                                        fileformat=HDF5))
    prt.discretize()
    prt.setup()

    simu = Simulation(nbIter=1)
    simu.initialize()
    op.apply(simu)
    prt.apply(simu)


if __name__ == '__main__':
    test_spectrum()
